import { useState, useRef } from 'react';
import { isDayBefore, isDayAfter, isSameDay } from './utils';
export function useDateRange(initialStartDate, initialEndDate) {
    const [startDate, setStartDate] = useState(initialStartDate);
    const [endDate, setEndDate] = useState(initialEndDate);
    const selection = useRef(false);
    function handleDayClick(day) {
        if (startDate && selection.current && !isDayBefore(day, startDate)) {
            setStartDate(startDate);
            setEndDate(day);
            selection.current = false;
        }
        else {
            setStartDate(day);
            setEndDate(undefined);
            selection.current = true;
        }
    }
    function handleDayHover(day) {
        if (startDate && selection.current && !isDayBefore(day, startDate)) {
            setEndDate(day);
        }
    }
    function processMonth(month) {
        return month.map((week) => week.map((day) => {
            const isStart = Boolean(startDate && isSameDay(day.date, startDate));
            const isEnd = Boolean(endDate && isSameDay(day.date, endDate));
            return Object.assign({}, day, { selected: isStart || isEnd, inRange: isStart ||
                    isEnd ||
                    Boolean(startDate &&
                        isDayAfter(day.date, startDate) &&
                        endDate &&
                        isDayBefore(day.date, endDate)), isStart,
                isEnd });
        }));
    }
    return { handleDayClick, handleDayHover, startDate, endDate, processMonth };
}
